<?php
use Nette\Utils\Strings,
	Nette\Image;

/**
 * Homepage presenter.
 */
class HomepagePresenter extends BasePresenter
{

	private $articlesRepository;
	private $regexp;
	private $category;


	protected function startup()
	{
		// Require login for accessing the pages
		parent::startup();
		$this->articlesRepository = $this->context->articlesRepository;

		if ($this->context->parameters['login']['required']){
			if (!$this->getUser()->isLoggedIn()) {
				$this->redirect('Sign:in');
			}
		}
	}

	public function renderArticle($id)
	{
		if (empty($id)){
			$this->redirect('default');
		}

		$article = $this->articlesRepository->findArticle($id)->fetch();

		$dom = $this->context->phpQuery;
		$dom = $dom->newDocument($article->body);
		$images = pq('img');

		foreach ($images as $image)
		{
			$imageSelector = pq($image);
			$imageUrl = $this->context->httpRequest->url->baseUrl . $this->context->parameters['images']['folder'] . $imageSelector->attr('src');
			$imageSelector->attr('src', $imageUrl);
			$imageSelector->attr('class', 'img-responsive');
			$imageSelector->attr('alt', 'image_alt');
		}
		$article->body = $dom->htmlOuter();
		$this->category = $article->category;
		$this->template->imageFolder = $this->context->parameters['images']['folder'];
		$this->template->article = $article;
		$this->template->category = $article->category;
	}


	public function renderCategories($id)
	{

		if (empty($id)){
			$this->redirect('default');
		}

		$paginator = $this['paginator']->getPaginator();
		$paginator->itemCount = $this->articlesRepository->getCategoryCount($id);

		$articles = $this->createPreview($this->articlesRepository->findCategory($id, $paginator->itemsPerPage, $paginator->offset ));

		$this->template->articles = $articles;
		$this->template->category = $id;
	}

	public function renderDefault()
	{

		$paginator = $this['paginator']->getPaginator();
		$paginator->itemCount = $this->articlesRepository->count;

		$articles = $this->createPreview( $this->articlesRepository->findAllLimit( $paginator->itemsPerPage, $paginator->offset ));

		$this->template->articles = $articles;
		$this->template->category = "Panorama";

	}

	protected function createComponentPaginator()
	{
		$visualPaginator = new VisualPaginatorControl();
		$visualPaginator->paginator->itemsPerPage = $this->context->parameters['page']['articlePerPage'];
		// $visualPaginator->paginator->itemCount = $this->articlesRepository->count;
		return $visualPaginator;
	}

	protected function createComponentTopStories()
	{
		return new TopStoriesControl($this->articlesRepository->findAllLimit(3,0));
	}

	protected function createComponentReadAlso()
	{
		return new ReadAlsoControl($this->articlesRepository->findCategory($this->category, 4, 0));
	}

	public function createPreview($selection)
	{

		$articles = array();

		foreach ($selection as $article)
		{
			$articles[] = array (
				// 'headings' => Strings::split($article->title,'~:\s~'),
				'headings' 	=> $article->title,
				'id' 		=> $article->id,
				'teaser' 	=> $article->teaser,
				'imageTag' 	=> "<img src=" . $this->context->httpRequest->url->baseUrl . $this->context->parameters['images']['folder'] . $article->images . " class=\"img-thumbnail img-responsive\" alt='" . $article->title . "'/>",
				'body' 		=> $article->body,
				'category' 	=> $article->category
			);
		}
		return $articles;
	}

}
