<?
require '../../libs/Nette/loader.php';
require('../../libs/phpQuery/phpQuery/phpQuery.php');

use Nette\Diagnostics\Debugger,
	Nette\Utils\Finder,
	Nette\Utils\Strings,
	Nette\Image;

Debugger::enable(); // enable Nette Debugger

/**
 * Define basic PHP constants - e.g. local image storage
 */
define("IMAGES_DIR", "/Users/stic/Sites/kepler_news/www/images/startup-pics/article_images/");
define("IMAGES_URL", "http://localhost:8888/kepler_news/www/images/startup-pics/article_images/");

$categories = array(
	'car',
	'culture',
	'economy',
	'health',
	'net',
	'panorama',
	'politics',
	'science',
	'sports',
	'travel' );

$lorem_title = 'Lorem ipsum';
$lorem_subtitle = 'Lorem ipsum dolor sit amet';
$lorem_teaser = '<p style="font-weight: bold;">Lorem ipsum dolor sit amet, consectetur adipiscing elit. Fusce accumsan eros ac erat mollis ultrices. Vestibulum lorem dolor, condimentum at congue quis, egestas sed neque. Nullam tempor condimentum urna, nec sollicitudin lacus pharetra sed. Suspendisse diam quam, tincidunt ac tristique in, egestas vitae tellus. Maecenas aliquam ultrices tempor. Quisque in lacus magna, egestas semper quam. Nunc iaculis interdum justo non dictum.</p>';

$lorem_body = '<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Fusce accumsan eros ac erat mollis ultrices. Vestibulum lorem dolor, condimentum at congue quis, egestas sed neque. Nullam tempor condimentum urna, nec sollicitudin lacus pharetra sed. Suspendisse diam quam, tincidunt ac tristique in, egestas vitae tellus. Maecenas aliquam ultrices tempor. Quisque in lacus magna, egestas semper quam. Nunc iaculis interdum justo non dictum.</p>

<p>In vitae dui sed turpis fringilla vestibulum. Nam accumsan, ante sed scelerisque sagittis, eros eros aliquam ante, at rutrum augue est quis lacus. Praesent eget enim augue. Nullam vitae nibh sit amet lacus pretium vulputate vitae in velit. Sed lobortis vestibulum libero nec porttitor. Aenean ipsum est, semper ut porttitor id, dictum id ipsum. Mauris diam est, accumsan vitae congue et, luctus consectetur magna. Vivamus varius varius nunc auctor vulputate. Ut sem erat, viverra sit amet pellentesque a, malesuada et lacus. Nulla facilisi.</p>

<p>Nunc gravida luctus felis nec euismod. Morbi volutpat, nisl sed posuere tristique, nunc felis fringilla urna, at euismod tellus arcu id odio. Aliquam suscipit aliquam elit, sed dictum felis consectetur nec. Sed velit mi, mattis non vestibulum quis, blandit nec mauris. Cras pellentesque porttitor lorem, nec ultricies elit commodo eu. Phasellus viverra blandit sapien ac rutrum. Proin volutpat, ipsum eu accumsan sagittis, metus justo vulputate velit, vel facilisis nisl ligula vitae mi. Phasellus eros nunc, ullamcorper nec tincidunt et, dictum et libero. Nulla sed lectus eget enim suscipit tempus.</p>

<p>Donec dapibus scelerisque sapien ac mollis. Nullam enim nulla, feugiat ac pulvinar a, condimentum sit amet magna. Cras elementum laoreet suscipit. Fusce sem tellus, fermentum et luctus ut, dictum at justo. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Phasellus euismod ipsum in diam dignissim id bibendum leo condimentum. In at lacinia mi. Mauris vel mi metus, id blandit felis. Vestibulum volutpat dictum sagittis. Curabitur tortor nibh, eleifend aliquam bibendum pharetra, condimentum vel massa. Nulla leo leo, interdum ut commodo at, consequat sed felis.</p>

<p>Nullam non nisi erat, elementum scelerisque nisi. Praesent adipiscing feugiat ipsum at elementum. Cras eros justo, feugiat eget fermentum at, convallis sit amet dui. Etiam venenatis, enim vel sagittis adipiscing, odio risus congue nisi, et auctor lacus nulla nec mauris. Sed a dolor sit amet velit iaculis interdum. Donec tempor diam ut ligula volutpat at scelerisque elit varius. Etiam aliquet egestas risus, et viverra urna euismod vel. Phasellus nulla magna, dapibus vitae auctor vel, mattis sed diam. Vestibulum leo diam, venenatis ut consectetur ut, facilisis eget mauris. Etiam eu enim at magna semper viverra.</p>';

/**
 * Database Conenction Credentials
 */
$mysql = array(
		'dsn' 		=> 'mysql:unix_socket=/Applications/MAMP/tmp/mysql/mysql.sock;dbname=kepler_news_init',
		'user' 		=> 'root',
		'password' 	=> 'root'
);

/**
 * DI Container for database connection and articles factory
 */
class DIContainer
{
	/** @var array $parameters - database connection parameters */
	private $parameters;
	/** @array Nette\Database\Connection */
	private $services = array();

	public function __construct(array $parameters){

		$this->parameters = $parameters;
	}

	public function createConnection()
	{

		return new Nette\Database\Connection(
			$this->parameters['dsn'],
			$this->parameters['user'],
			$this->parameters['password']
		);
	}

	public function getConnection()
	{

		if(!isset($this->services['connection'])) {
			$this->services['connection'] = $this->createConnection();
		}
		return $this->services['connection'];
	}

	/**
	 * Factory for Article class
	 */
	public function createArticle()
	{

		return new Article($this->getConnection());
	}

}

/**
 * Class for working with article and storing it to database
 */
class Article
{
	/** @var array content */
	public $content;
	/** @var Nette\Database\Connection connection */
	public $connection;


	public function __construct(Nette\Database\Connection $connection)
	{
		$this->connection = $connection;
	}

	/**
	 * Save article to the database
	 */
	public function save()
	{
		// Debugger::dump($this->content);
		return $this->connection->table('articles')->insert(array(
			'guid'			=> $this->content['guid'],
			'title'			=> $this->content['title'],
			'link'			=> $this->content['link'],
			'category'		=> $this->content['category'],
			'description'	=> $this->content['description'],
			'images'		=> $this->content['imgs'],
			'teaser'		=> $this->content['teaser'],
			'body'			=> $this->content['body'],
			'pub_date'		=> $this->content['pubDate']
		));
	}

}


// Create DI container
$container = new DIContainer($mysql);

foreach ($categories as $category) {
	foreach (Finder::findFiles('*')->in(IMAGES_DIR . $category . "/") as $key => $file) {

		// Debugger::dump($file->getFileName());
		// Debugger::dump($key);

		$art = $container->createArticle();
		$int= mt_rand(1325375999,1356998399);
		$art->content = array(
				'guid' 			=> 'init',
				'title' 		=> $lorem_title . ": " . $lorem_subtitle,
				'link' 			=> 'init',
				'category' 		=> $category,
				'description'	=> 'descripton',
				'imgs'			=> $category . "/" . $file->getFileName() ,
				'teaser'		=> $lorem_teaser,
				'body'			=> $lorem_body,
				'pubDate'		=> date('Y-m-d H:i:s', $int)
			);

		$art->save();

		Debugger::dump($art->content);

	}
}
